@@ -1,11 +1,12 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "ffmpeg-player" "0.2.1"
+(define-package "ffmpeg-player" "20260101.559"
   "Play video using ffmpeg."
   '((emacs "24.4")
     (s     "1.12.0")
     (f     "0.20.0"))
   :url "https://github.com/jcs-elpa/ffmpeg-player"
-  :commit "164fb15d70adbc186eb2d987f5c5143aa7336659"
-  :revdesc "164fb15d70ad"
+  :commit "97205aa6c47875c75d10385f22ea0ef3c8a1a880"
+  :revdesc "97205aa6c478"
+  :keywords '("multimedia" "video" "ffmpeg" "buffering" "images")
   :authors '(("Jen-Chieh" . "jcs090218@gmail.com"))
   :maintainers '(("Jen-Chieh" . "jcs090218@gmail.com")))
